import React, { useEffect, useState } from "react";
import {
  ModalForm,
  ProFormText,
  ProFormDependency,
} from "@ant-design/pro-components";
import md5 from "md5";
import { changePassword } from "@/services/login";
import { useNavigate } from "react-router-dom";
import { useTranslation } from 'react-i18next';

export default (props) => {
  const { visible, setVisible } = props;
  const navigate = useNavigate();
  const { t } = useTranslation();

  const onFinish = async (values) => {
    const data = {
      originPassword: md5(values.password),
      newPassword: md5(values.newPassword),
    };
    await changePassword(data);
    navigate(`/qLogin`);

    return true;
  };

  return (
    <ModalForm
      title={t('accountsettings.passwordTitle')}
      width="480px"
      open={visible}
      modalProps={{
        onCancel: () => setVisible(false),
      }}
      onFinish={onFinish}
    >
      <ProFormText.Password
        label={t('accountsettings.passwordInput1')}
        name="password"
        rules={[{ required: true }]}
      />
      <ProFormText.Password
        label={t('accountsettings.passwordInput2')}
        name="newPassword"
        rules={[{ required: true }]}
      />

      <ProFormDependency name={["newPassword"]}>
        {({ newPassword }) => (
          <ProFormText.Password
            label={t('accountsettings.passwordInputLabel')}
            name="newPassword2"
            rules={[
              { required: true, message: t('accountsettings.passwordInputLabelRule') },
              () => ({
                validator (_, value) {
                  if (!value || value == newPassword) {
                    return Promise.resolve();
                  }

                  return Promise.reject(t('accountsettings.passwordInputPromiseText'));
                },
              }),
            ]}
          />
        )}
      </ProFormDependency>
    </ModalForm>
  )
}