import React, { useEffect, useState } from "react";
import {
  ModalForm,
  ProFormText,
  ProFormDependency,
} from "@ant-design/pro-components";
import md5 from "md5";
import { changePhone } from "@/services/login";
import { useNavigate } from "react-router-dom";
import { useTranslation } from 'react-i18next';

export default (props) => {
  const { opPhone, setOpPhone } = props;
  const navigate = useNavigate();
  const { t } = useTranslation();

  const onFinish = async (values) => {
    const data = {
      originPhone: values.phone,
      newPhone: values.newPhone,
    };
    await changePhone(data);
    navigate(`/qLogin`);

    return true;
  };

  return (
    <ModalForm
      title={t('accountsettings.emailTitle')}
      width="480px"
      open={opPhone}
      modalProps={{
        onCancel: () => setOpPhone(false),
      }}
      onFinish={onFinish}
    >
      <ProFormText
        label={t('accountsettings.phoneInput1')}
        name="phone"
        rules={[{ required: true }]}
      />
      <ProFormText
        label={t('accountsettings.phoneInput2')}
        name="newPhone"
        rules={[{ required: true }]}
      />

      <ProFormDependency name={["newPhone"]}>
        {({ newPhone }) => (
          <ProFormText
            label={t('accountsettings.phoneInputLabel')}
            name="newPhone2"
            rules={[
              { required: true, message: t('accountsettings.phoneInputLabelRule') },
              () => ({
                validator (_, value) {
                  if (!value || value == newPhone) {
                    return Promise.resolve();
                  }

                  return Promise.reject(t('accountsettings.phoneInputPromiseText'));
                },
              }),
            ]}
          />
        )}
      </ProFormDependency>
    </ModalForm>
  )
}